var map = L.map('map').setView([20.5937, 78.9629], 5);

L.tileLayer('https://api.mapbox.com/styles/v1/{id}/tiles/{z}/{x}/{y}?access_token={accessToken}', {
  attribution: '&copy; <a href="https://www.mapbox.com/attributions/">Mapbox</a>',
  maxZoom: 30,
  id: 'mapbox/streets-v11',
  accessToken: 'pk.eyJ1Ijoic3JpeWEtMTU0MyIsImEiOiJjbGhqN2xndjYwZjgwM25xcDk2MmN6d2VlIn0.g7O5PGGfPljgpC9g-oCS5w'
}).addTo(map);

// Read markers from CSV
d3.csv('markers.csv').then(function(data) {
  var markers = data.map(function(d) {
    return {
      lat: +d.lat,
      lng: +d.lng,
      name: d.name,
      pm: +d.pm
    };
  });

  // Add markers using D3
  var svgMarkers = d3.select(map.getPanes().overlayPane)
    .selectAll('.marker')
    .data(markers)
    .enter()
    .append('svg')
    .attr('class', 'marker')
    .each(function (d) {
      var svg = d3.select(this);
      var marker = map.latLngToLayerPoint([d.lat, d.lng]);

      svg.style('left', (marker.x - 10) + 'px')
        .style('top', (marker.y - 10) + 'px');

      svg.append('circle')
        .attr('r', 10)
        .attr('cx', 10)
        .attr('cy', 10)
        .classed('green', d.pm <= 100)
        .classed('orange', d.pm > 100);

      svg.append('text')
        .text(d.name)
        .attr('x', 20)
        .attr('y', 10);

      svg.on('click', function() {
        var latLng = L.latLng(d.lat, d.lng);
        var popupContent = '<b>' + d.name + '</b><br>Coordinates: ' + latLng.toString() + '<br><br>' +
          '<canvas id="chart-' + d.name + '" class="chart"></canvas>';

        var popup = L.popup()
          .setLatLng(latLng)
          .setContent(popupContent)
          .openOn(map);

        var chartId = 'chart-' + d.name;
        generateGraph(chartId, d.pm);
      });
    });

  function updateMarkers() {
    var zoomLevel = map.getZoom();

    svgMarkers.each(function (d) {
      var svg = d3.select(this);
      var marker = map.latLngToLayerPoint([d.lat, d.lng]);
      var scaledRadius = 20 * Math.pow(2, zoomLevel - 5);

      svg.style('left', (marker.x - scaledRadius) + 'px')
        .style('top', (marker.y - scaledRadius) + 'px');

      svg.select('circle')
        .attr('r', scaledRadius)
        .attr('cx', scaledRadius)
        .attr('cy', scaledRadius)
        .classed('green', d.pm <= 100)
        .classed('orange', d.pm > 100);

      svg.select('text')
        .attr('x', scaledRadius * 2)
        .attr('y', scaledRadius);
    });
  }

  map.on('zoomend', updateMarkers);
  map.on('moveend', updateMarkers);

  updateMarkers(); // Initial marker update
});
